MLHub Package
=============

Visit the new MLHub Book at https://survivor.togaware.com/mlhub/

MLHub packages represent the latest state of the art in AI, Machine
Learning and Data Science. Each package provides demonstrations and
utilities to make AI accessible to you.

The MLHub package provides the ml command line tool to manage MLHub
packages: install, configure, demo, run.

The MLHub also provides the Python and R mlhub packages to support
package developers.

The python mlhub package is installed from PyPI:

	$ pip3 install mlhub

The R mlhub package can be installed from github:

	$ sudo Rscript -e 'devtools::install_github("mlhubber/mlhub@main", quiet=TRUE)'

